import * as React from 'react';
import { RouteComponentProps, RouteProps, Route } from 'react-router-dom';
import { Container, Menu, Sidebar, Segment, Icon, Breadcrumb, Grid, Dropdown } from 'semantic-ui-react';
import { Header } from './Header';
import { Footer } from './Footer';
import LeftMenu from './LeftMenu';

import ProbeList from '../monitoring/probe/List';
import SensorList from '../monitoring/sensor/List';
import SensorSetup from '../monitoring/sensor/Setup';

export interface Props extends RouteComponentProps<any> {
}
export interface State {
  sidebar_visible: boolean;
  notification_visible: boolean;
}

export class AppLayout extends React.Component<Props, State> {

  constructor(props: Props, context: State) {
    super(props, context);
    this.state = {
      sidebar_visible: true,
      notification_visible: false,
    };
  }

  public onSidebar = () => {
    this.setState({ notification_visible: !this.state.notification_visible, sidebar_visible: !this.state.sidebar_visible });
  }

  public render(): JSX.Element {
    return (
      <Container fluid>
        <LeftMenu />
        <Segment vertical style={{ margin: '0 0 0 210px', padding: '0' }}>
          <Header />

          <Route path={`${this.props.match.url}/probe`} component={ProbeList} />
          <Route path={`${this.props.match.url}/sensor_list`} component={SensorList} />
          <Route path={`${this.props.match.url}/sensor_setup`} component={SensorSetup} />

          <Footer />
        </Segment>
      </Container >
    );
  }
}

export default AppLayout;

