import * as React from 'react';
import { Table, Button, Header, Container } from 'semantic-ui-react';
import SensorDetailContainer from '../SensorDetail';

import Probe from '@overflow/probe/api/model/Probe';
import Sensor from '@overflow/sensor/api/model/Sensor';
import Target from '@overflow/target/api/model/Target';
import Domain from '@overflow/domain/api/model/Domain';

export interface StateProps {
  probe?: Probe;
  target?: Target;
}

export interface DispatchProps {
  onReadAllByTarget?(target: Target): void;
  onReadAllByProbe?(probe: Probe): void;
  onReadAllByDomain?(domain: Domain): void;
}

export type SensorListProps = StateProps & DispatchProps;

export interface SensorListState {
  isDetail: boolean;
  selected: Sensor;
}


export class SensorList extends React.Component<SensorListProps, SensorListState> {

  private data: any;

  constructor(props: SensorListProps, context: SensorListState) {
    super(props, context);
    this.state = {
      selected: null,
      isDetail: false, // temp
    };
  }

  public componentWillMount(): void {
    // super.componentWillMount();
    this.data = [
      {
        'id': '111',
        'metaSensorStatus': {
          'name': 'NORMAL',
        },
        'target': {
          'id': '1',
        },
        'metaCrawler': {
          'name': 'WMI',
          'description': 'WMI description',
        },
        'crawlerInputItems': 'json value',
        'description': 'description1111111111',
      },
      {
        'id': '222',
        'metaSensorStatus': {
          'name': 'NORMAL',
        },
        'target': {
          'id': '1',
        },
        'metaCrawler': {
          'name': 'SNMP',
          'description': 'SNMP description',
        },
        'crawlerInputItems': 'json value',
        'description': 'description1111111111',
      },
      {
        'id': '333',
        'metaSensorStatus': {
          'name': 'NORMAL',
        },
        'target': {
          'id': '1',
        },
        'metaCrawler': {
          'name': 'JMX',
          'description': 'JMX description',
        },
        'crawlerInputItems': 'json value',
        'description': 'description1111111111',
      },
    ];
  }

  public handleSelect(selectedSensor: Sensor): void {
    this.setState({
      selected: selectedSensor,
      isDetail: true,
    });
  }

  public checkCellStatus(status: any): boolean {
    if (status.name === 'STOPPED') {
      return true;
    }
    return false;
  }

  public showStartStopBtn(status: any): JSX.Element {
    if (status.name === 'STARTED') {
      return <Button content='Stop' icon='stop' labelPosition='left' color={'blue'} floated={'right'} onClick={this.handleStartStop} />;
    } else {
      return <Button content='Start' icon='play' labelPosition='left' color={'blue'} floated={'right'} onClick={this.handleStartStop} />;
    }
  }

  public handleStartStop(event: any, data: any): void {
    console.log(event);
  }
  public handleAddSensor(): void {
    console.log('adding a sensor');
  }

  public render(): JSX.Element {
    if (this.state.isDetail) {
      // return (<SensorDetailContainer sensor={this.state.selected} />);
       return (<SensorDetailContainer />);
    }
    return (
      <Container fluid>
        <Header as='h3' dividing>Sensors</Header>
        <Table celled selectable striped>
          <Table.Header>
            <Table.Row>
              <Table.HeaderCell textAlign={'center'}>No.</Table.HeaderCell>
              <Table.HeaderCell textAlign={'center'}>Status</Table.HeaderCell>
              <Table.HeaderCell textAlign={'center'}>Crawler</Table.HeaderCell>
              <Table.HeaderCell textAlign={'center'}>Description</Table.HeaderCell>
              <Table.HeaderCell textAlign={'center'}>Item count</Table.HeaderCell>
            </Table.Row>
          </Table.Header>

          <Table.Body>
            {this.data.map((sensor: any, index: number) => (
              <Table.Row key={index} onClick={this.handleSelect.bind(this, sensor)}>
                <Table.Cell textAlign={'center'}>{index + 1}</Table.Cell>
                <Table.Cell negative={this.checkCellStatus(sensor.metaSensorStatus)} textAlign={'center'}>
                  {sensor.metaSensorStatus.name}
                </Table.Cell>
                <Table.Cell>{sensor.metaCrawler.name}</Table.Cell>
                <Table.Cell>{sensor.description}</Table.Cell>
                <Table.Cell>to do</Table.Cell>
                {/* <Table.Cell collapsing>{this.showStartStopBtn(sensor.metaSensorStatus)}</Table.Cell> */}
              </Table.Row>
            ))}
          </Table.Body>
        </Table>
        <Button content='Add' icon='add' labelPosition='left' floated='right' positive onClick={this.handleAddSensor.bind(this)} />
      </Container>
    );
  }

}



